PluginManager

Struct PluginManager 

pub struct PluginManager { /* private fields */ }
๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

Plugin manager

Implementations

Source

impl PluginManager

pub fn new() -> Self

๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

Create new plugin manager

pub fn with_override() -> Self

๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

Create plugin manager with override allowed

pub fn register_plugin( &self, plugin: Arc<dyn ProtocolPlugin>, ) -> Result<(), TransportError>

๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

Register plugin

pub fn unregister_plugin(&self, name: &str) -> Result<(), TransportError>

๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

Unregister plugin

pub fn get_plugin(&self, name: &str) -> Option<Arc<dyn ProtocolPlugin>>

๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

Get plugin

pub fn list_protocols(&self) -> Vec<String>

๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

List all protocols (including builtin and plugins)

pub fn get_protocol_info(&self, name: &str) -> Option<PluginInfo>

๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

Get protocol information

pub async fn create_server_with_plugin( &self, protocol: &str, config: Box<dyn Any>, ) -> Result<Box<dyn Server>, TransportError>

๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

Create server with plugin

pub async fn create_connection_factory_with_plugin( &self, protocol: &str, config: Box<dyn Any>, ) -> Result<Box<dyn ConnectionFactory>, TransportError>

๐Ÿ‘ŽDeprecated since 1.0.9:

experimental plugin system, not wired into the transport path; scheduled for removal in 2.0

Create connection factory with plugin