pub struct PluginManager { /* private fields */ }experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
Plugin manager
Implementations
Sourceimpl PluginManager
impl PluginManager
Sourcepub fn new() -> Self
๐Deprecated since 1.0.9: experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
pub fn new() -> Self
experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
Create new plugin manager
Sourcepub fn with_override() -> Self
๐Deprecated since 1.0.9: experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
pub fn with_override() -> Self
experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
Create plugin manager with override allowed
Sourcepub fn register_plugin(
&self,
plugin: Arc<dyn ProtocolPlugin>,
) -> Result<(), TransportError>
๐Deprecated since 1.0.9: experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
pub fn register_plugin( &self, plugin: Arc<dyn ProtocolPlugin>, ) -> Result<(), TransportError>
experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
Register plugin
Sourcepub fn unregister_plugin(&self, name: &str) -> Result<(), TransportError>
๐Deprecated since 1.0.9: experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
pub fn unregister_plugin(&self, name: &str) -> Result<(), TransportError>
experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
Unregister plugin
Sourcepub fn get_plugin(&self, name: &str) -> Option<Arc<dyn ProtocolPlugin>>
๐Deprecated since 1.0.9: experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
pub fn get_plugin(&self, name: &str) -> Option<Arc<dyn ProtocolPlugin>>
experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
Get plugin
Sourcepub fn list_protocols(&self) -> Vec<String>
๐Deprecated since 1.0.9: experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
pub fn list_protocols(&self) -> Vec<String>
experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
List all protocols (including builtin and plugins)
Sourcepub fn get_protocol_info(&self, name: &str) -> Option<PluginInfo>
๐Deprecated since 1.0.9: experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
pub fn get_protocol_info(&self, name: &str) -> Option<PluginInfo>
experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
Get protocol information
Sourcepub async fn create_server_with_plugin(
&self,
protocol: &str,
config: Box<dyn Any>,
) -> Result<Box<dyn Server>, TransportError>
๐Deprecated since 1.0.9: experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
pub async fn create_server_with_plugin( &self, protocol: &str, config: Box<dyn Any>, ) -> Result<Box<dyn Server>, TransportError>
experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
Create server with plugin
Sourcepub async fn create_connection_factory_with_plugin(
&self,
protocol: &str,
config: Box<dyn Any>,
) -> Result<Box<dyn ConnectionFactory>, TransportError>
๐Deprecated since 1.0.9: experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
pub async fn create_connection_factory_with_plugin( &self, protocol: &str, config: Box<dyn Any>, ) -> Result<Box<dyn ConnectionFactory>, TransportError>
experimental plugin system, not wired into the transport path; scheduled for removal in 2.0
Create connection factory with plugin